<img width="300px" src="https://sickrage.ca/img/logo-stacked.png" />

# 

##Sun Aug 09 2020 18:03:01 GMT+0000 (Coordinated Universal Time)


## Bug Fixes
  - Fixed issue with v16 database migration using multiple where clauses
  ([135dea3c](https://gitlab-ci-token:Fy1Ve1DtH1MW-Dve-y_-@git.sickrage.ca/SiCKRAGE/sickrage/commit/135dea3c4cb176fefb891a8d5023731753c6810a))




